@@ -25,12 +25,13 @@ HTLC_HDR_MSG HTLC_HDR_NEWS_GETFILE HTLC_HDR_NEWS_POST HTLC_HDR_PCHAT_ACCEPT
 HTLC_HDR_PCHAT_CLOSE HTLC_HDR_PCHAT_CREATE HTLC_HDR_PCHAT_DECLINE
 HTLC_HDR_PCHAT_INVITE HTLC_HDR_PCHAT_SUBJECT HTLC_HDR_USER_CHANGE
 HTLC_HDR_USER_CREATE HTLC_HDR_USER_GETINFO HTLC_HDR_USER_GETLIST
-HTLC_HDR_USER_KICK HTLC_HDR_USER_OPEN HTLC_MACOS_TO_UNIX_TIME HTLC_MAGIC
-HTLC_MAGIC_LEN HTLC_MAX_PATHLEN HTLC_NEWLINE HTLC_TASK_FILE_DELETE
-HTLC_TASK_FILE_GET HTLC_TASK_FILE_INFO HTLC_TASK_FILE_LIST
-HTLC_TASK_FILE_MKDIR HTLC_TASK_FILE_MOVE HTLC_TASK_FILE_PUT HTLC_TASK_KICK
-HTLC_TASK_LOGIN HTLC_TASK_NEWS HTLC_TASK_NEWS_POST HTLC_TASK_SEND_MSG
-HTLC_TASK_SET_INFO HTLC_TASK_USER_INFO HTLC_TASK_USER_LIST
+HTLC_HDR_USER_KICK HTLC_HDR_USER_OPEN HTLC_INFO_FALIAS_TYPE
+HTLC_INFO_FOLDER_TYPE HTLC_MACOS_TO_UNIX_TIME HTLC_MAGIC HTLC_MAGIC_LEN
+HTLC_MAX_PATHLEN HTLC_NEWLINE HTLC_TASK_FILE_DELETE HTLC_TASK_FILE_GET
+HTLC_TASK_FILE_INFO HTLC_TASK_FILE_LIST HTLC_TASK_FILE_MKDIR
+HTLC_TASK_FILE_MOVE HTLC_TASK_FILE_PUT HTLC_TASK_KICK HTLC_TASK_LOGIN
+HTLC_TASK_NEWS HTLC_TASK_NEWS_POST HTLC_TASK_SEND_MSG HTLC_TASK_SET_INFO
+HTLC_TASK_USER_INFO HTLC_TASK_USER_LIST HTLC_UNIX_TO_MACOS_TIME
 HTLS_DATA_AGREEMENT HTLS_DATA_CHAT HTLS_DATA_COLOR HTLS_DATA_FILE_COMMENT
 HTLS_DATA_FILE_CREATOR HTLS_DATA_FILE_CTIME HTLS_DATA_FILE_ICON
 HTLS_DATA_FILE_LIST HTLS_DATA_FILE_MTIME HTLS_DATA_FILE_NAME
@@ -44,13 +45,16 @@ HTLS_HDR_PCHAT_INVITE HTLS_HDR_PCHAT_SUBJECT HTLS_HDR_PCHAT_USER_CHANGE
 HTLS_HDR_PCHAT_USER_LEAVE HTLS_HDR_POLITE_QUIT HTLS_HDR_TASK
 HTLS_HDR_USER_CHANGE HTLS_HDR_USER_LEAVE HTLS_MAGIC HTLS_MAGIC_LEN
 HTLS_TCPPORT HTRK_MAGIC HTRK_MAGIC_LEN HTRK_TCPPORT HTRK_UDPPORT
-HTXF_BUFSIZE HTXF_MAGIC HTXF_MAGIC_LEN HTXF_RFLT_MAGIC HTXF_TCPPORT
+HTXF_BUFSIZE HTXF_MAGIC HTXF_MAGIC_LEN HTXF_PARTIAL_CREATOR
+HTXF_PARTIAL_TYPE HTXF_RESUME_MAGIC HTXF_RFLT_MAGIC HTXF_TCPPORT
 PATH_SEPARATOR SIZEOF_HL_DATA_HDR SIZEOF_HL_FILE_FORK_HDR
-SIZEOF_HL_FILE_LIST_HDR SIZEOF_HL_FILE_XFER_HDR SIZEOF_HL_LONG_HDR
-SIZEOF_HL_PROTO_HDR SIZEOF_HL_SHORT_HDR SIZEOF_HL_TASK_FILLER
-SIZEOF_HL_USER_LIST_HDR);
+SIZEOF_HL_FILE_LIST_HDR SIZEOF_HL_FILE_UPLOAD_HDR SIZEOF_HL_FILE_XFER_HDR
+SIZEOF_HL_LONG_HDR SIZEOF_HL_PROTO_HDR SIZEOF_HL_SHORT_HDR
+SIZEOF_HL_TASK_FILLER SIZEOF_HL_USER_LIST_HDR);
 
-%EXPORT_TAGS = ('ALL' => \@EXPORT_OK);
+%EXPORT_TAGS = ('all' => \@EXPORT_OK);
+
+$Net::Hotline::Constants::VERSION = '0.60';
 
 use constant PATH_SEPARATOR => ($^O eq 'MacOS') ? ':' : '/';
 
@@ -63,15 +67,23 @@ use constant PATH_SEPARATOR => ($^O eq 'MacOS') ? ':' : '/';
 # times returned by Hotline to get the time since the unix epoch.
 use constant HTLC_MACOS_TO_UNIX_TIME => -2082830400;
 
-use constant HTLC_FOLDER_TYPE     => 'fldr';
+# Add this constant to Unix times to get Hotline (Mac OS) times
+use constant HTLC_UNIX_TO_MACOS_TIME =>  2082830400;
 
-use constant HTLC_DEFAULT_NICK    => 'guest';
-use constant HTLC_DEFAULT_LOGIN   => 'guest';
-use constant HTLC_DEFAULT_ICON    => 410;
+use constant HTLC_FOLDER_TYPE      => 'fldr';
+use constant HTXF_PARTIAL_TYPE     => 'HTft';
+use constant HTXF_PARTIAL_CREATOR  => 'HTLC';
 
-use constant HTLC_EWOULDBLOCK     => 2; # Can be anything > 1, really
+use constant HTLC_INFO_FOLDER_TYPE => 'Folder';
+use constant HTLC_INFO_FALIAS_TYPE => 'Folder Alias';
 
-use constant HTLC_MAX_PATHLEN     => 255;
+use constant HTLC_DEFAULT_NICK     => 'guest';
+use constant HTLC_DEFAULT_LOGIN    => 'guest';
+use constant HTLC_DEFAULT_ICON     => 410;
+
+use constant HTLC_EWOULDBLOCK      => 2; # Can be anything > 1, really
+
+use constant HTLC_MAX_PATHLEN      => 255;
 
 # Arbitrary unique task type constants
 use constant HTLC_TASK_FILE_DELETE => 1;
@@ -100,15 +112,16 @@ use constant HTXF_BUFSIZE   => 4096;
 
 use constant HTLC_NEWLINE   => "\015";
 
-use constant HTLC_MAGIC      => pack("c12", 84, 82, 84, 80, 72, 79, 84, 76, 0, 1, 0, 2);
-use constant HTLC_MAGIC_LEN  => 12;
-use constant HTLS_MAGIC      => pack("c8", 84, 82, 84, 80, 0, 0, 0, 0);
-use constant HTLS_MAGIC_LEN  => 8;
-use constant HTRK_MAGIC	     => pack("c6", 72, 84, 82, 75, 0, 1);
-use constant HTRK_MAGIC_LEN  => 6;
-use constant HTXF_MAGIC	     => pack("c4", 72, 84, 88, 70);
-use constant HTXF_MAGIC_LEN  => 4;
-use constant HTXF_RFLT_MAGIC => pack("c4", 82, 70, 76, 84);
+use constant HTLC_MAGIC        => pack("c12", 84, 82, 84, 80, 72, 79, 84, 76, 0, 1, 0, 2);
+use constant HTLC_MAGIC_LEN    => 12;
+use constant HTLS_MAGIC        => pack("c8", 84, 82, 84, 80, 0, 0, 0, 0);
+use constant HTLS_MAGIC_LEN    => 8;
+use constant HTRK_MAGIC	       => pack("c6", 72, 84, 82, 75, 0, 1);
+use constant HTRK_MAGIC_LEN    => 6;
+use constant HTXF_MAGIC	       => pack("c4", 72, 84, 88, 70);
+use constant HTXF_MAGIC_LEN    => 4;
+use constant HTXF_RFLT_MAGIC   => pack("c4", 82, 70, 76, 84);
+use constant HTXF_RESUME_MAGIC => pack("n3", 0x00CC, 0x0002, 0x0001);
 
 use constant HTLC_HDR_CHAT              => 0x00000069;
 use constant HTLC_HDR_FILE_DELETE       => 0x000000CC;
@@ -204,6 +217,7 @@ use constant SIZEOF_HL_FILE_LIST_HDR    => 24;
 use constant SIZEOF_HL_USER_LIST_HDR    => 12;
 use constant SIZEOF_HL_TASK_FILLER      => 2;
 use constant SIZEOF_HL_FILE_XFER_HDR    => 40;
+use constant SIZEOF_HL_FILE_UPLOAD_HDR  => 111;
 use constant SIZEOF_HL_FILE_FORK_HDR    => 16;
 
 1;
